@@ -2,6 +2,8 @@
 #
 # Encoding of Arabic: ArabTeX Notation by Klaus Lagally #####################################
 
+# $Id: RE.pm 143 2006-11-15 01:16:57Z smrz $
+
 package Encode::Arabic::ArabTeX::RE;
 
 use 5.008;
@@ -11,6 +13,9 @@ use warnings;
 
 use Scalar::Util 'blessed';
 
+our $VERSION = do { q $Revision: 143 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
+
+
 use Encode::Encoding;
 use base 'Encode::Encoding';
 
@@ -44,7 +49,6 @@ our %modemap = (
 
 sub import {            # perform import as if Encode were used one level before this module
     require Encode;
-    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
     Encode->export_to_level(1, @_);
 }
 
@@ -102,27 +106,25 @@ sub encode ($$;$) {
 
     no strict 'refs';
 
-    if (defined ${ $cls . '::enmode' } and ${ $cls . '::enmode' } == 3) {
+    if (${ $cls . '::enmode' } == 3) {
 
         $text =~ s/\\vow{(.+?)}/$1/g;
         $text =~ s/\\aux{(.+?)}/"$1/g;
         $text =~ s/\\sukun{}/"/g;
     }
-    elsif (defined ${ $cls . '::enmode' } and ${ $cls . '::enmode' } == 2) {
+    elsif (${ $cls . '::enmode' } == 2) {
 
         $text =~ s/\\vow{(.+?)}/"$1/g;
         $text =~ s/\\aux{(.+?)}/$1/g;
         $text =~ s/\\sukun{}/"/g;
     }
-    elsif (defined ${ $cls . '::enmode' } and ${ $cls . '::enmode' } == 4) {
+    elsif (${ $cls . '::enmode' } == 4) {
 
         $text =~ s/\\vow{(.+?)}/$1/g;
         $text =~ s/\\aux{(.+?)}/$1/g;
         $text =~ s/\\sukun{}//g;
     }
 
-    $text = Encode::encode "utf8", $text if Encode::is_utf8($text);
-
     return $text;
 }
 
@@ -133,8 +135,6 @@ sub decode ($$;$) {
 
     $_[1] = '' if $check;                   # this is what in-place edit needs
 
-    $text = Encode::decode "utf8", $text unless Encode::is_utf8($text);
-
     $cls->initialize_decode() unless %decode_used;
 
     $text = "\n" . $text . "\n";
@@ -404,6 +404,11 @@ __END__
 Encode::Arabic::ArabTeX::RE - Deprecated Encode::Arabic::ArabTeX implemented with regular expressions
 
 
+=head1 REVISION
+
+    $Revision: 143 $        $Date: 2006-11-15 02:16:57 +0100 (Wed, 15 Nov 2006) $
+
+
 =head1 SYNOPSIS
 
     use Encode::Arabic::ArabTeX::RE;
@@ -432,12 +437,16 @@ L<Encode::Arabic::ArabTeX|Encode::Arabic::ArabTeX>
 
 =head1 AUTHOR
 
-Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
+Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
+
+    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
+
+Perl is also designed to make the easy jobs not that easy ;)
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2012 Otakar Smrz
+Copyright 2003-2006 by Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
