@@ -2,6 +2,8 @@
 #
 # Encoding of Arabic: ArabTeX Notation by Klaus Lagally, Verbatim #############################
 
+# $Id: Verbatim.pm 143 2006-11-15 01:16:57Z smrz $
+
 package Encode::Arabic::ArabTeX::Verbatim;
 
 use 5.008;
@@ -11,6 +13,9 @@ use warnings;
 
 use Carp;
 
+our $VERSION = do { q $Revision: 143 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
+
+
 use Encode::Arabic::ArabTeX ();
 use base 'Encode::Arabic::ArabTeX';
 
@@ -105,9 +110,7 @@ sub import {            # perform import as if Encode were used one level before
 
     require Encode;
 
-    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
-
-    Encode->export_to_level(1, @_);
+    Encode->export_to_level(1, @_);     # here comes the only trick ^^
 }
 
 
@@ -1131,16 +1134,12 @@ sub demoder ($$@) {
                     "\"\x{064E}\x{0627}\"\x{0652}",     "\x{0627}\x{0652}",
 
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         "\x{0644}" . $_ . "\x{064E}\x{0627}\"\x{0652}",     "\x{0644}\x{0627}" . $_ . "\x{064E}\x{0652}",
                         "\x{0644}" . $_ . "\"\x{064E}\x{0627}\"\x{0652}",   "\x{0644}\x{0627}" . $_ . "\x{0652}",
 
                     } "", "\x{0651}"
-
-                    ) : () ),
                 ),
 
                     "\x{064E}\x{0649}\"\x{0652}",       "\x{064E}\x{0649}\x{0652}",
@@ -1205,8 +1204,6 @@ sub demoder ($$@) {
 
                 # laam + 'alif .. either enforce ligatures, or shuffle the diacritics
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $alif = $_;
@@ -1227,13 +1224,9 @@ sub demoder ($$@) {
                           "\x{0652}"
 
                     } "\x{0622}", "\x{0623}", "\x{0625}", "\x{0627}"    #, "\x{0671}"
-
-                    ) : () ),
                 ),
 
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $vowel = $_;
@@ -1248,14 +1241,10 @@ sub demoder ($$@) {
                     } "\x{064E}", "\x{064F}", "\x{0650}",
                       "\x{064B}", "\x{064C}", "\x{064D}",
                       "\x{0652}"
-
-                    ) : () ),
                 ),
 
                 # laam + vowel + 'alif + vowel .. internal substitution with wa.sla
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $double = $_;
@@ -1279,8 +1268,6 @@ sub demoder ($$@) {
                        } "\x{064E}", "\x{064F}", "\x{0650}"
 
                     } "", "\x{0651}"
-
-                    ) : () ),
                 ),
 
                 # optional ligatures to enforce here
@@ -1364,8 +1351,6 @@ sub demoder ($$@) {
 
                 # laam + 'alif .. either enforce ligatures, or shuffle the diacritics
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $alif = $_;
@@ -1386,13 +1371,9 @@ sub demoder ($$@) {
                           # "\x{0652}"
 
                     } "\x{0622}", "\x{0623}", "\x{0625}", "\x{0627}", "\x{0671}"
-
-                    ) : () ),
                 ),
 
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $alif = $_;
@@ -1405,14 +1386,10 @@ sub demoder ($$@) {
                         } "", "\x{0651}"
 
                     } "\x{0622}", "\x{0623}", "\x{0625}", "\x{0627}", "\x{0671}"
-
-                    ) : () ),
                 ),
 
                 # laam + vowel + 'alif + vowel .. internal substitution with wa.sla
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $double = $_;
@@ -1436,8 +1413,6 @@ sub demoder ($$@) {
                        } "\x{064E}", "\x{064F}", "\x{0650}"
 
                     } "", "\x{0651}"
-
-                    ) : () ),
                 ),
 
                 # optional ligatures to enforce here
@@ -1483,8 +1458,6 @@ sub demoder ($$@) {
 
                 # laam + 'alif .. either enforce ligatures, or shuffle the diacritics
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $alif = $_;
@@ -1505,8 +1478,6 @@ sub demoder ($$@) {
                           "\x{0652}"
 
                     } "\x{0622}", "\x{0623}", "\x{0625}", "\x{0627}", "\x{0671}"
-
-                    ) : () ),
                 ),
 
                 # laam + vowel + 'alif + vowel .. internal substitution with wa.sla
@@ -1574,8 +1545,6 @@ sub demoder ($$@) {
 
                 # laam + 'alif .. either enforce ligatures, or shuffle the diacritics
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $alif = $_;
@@ -1596,14 +1565,10 @@ sub demoder ($$@) {
                           "\x{0652}"
 
                     } "\x{0622}", "\x{0623}", "\x{0625}", "\x{0627}", "\x{0671}"
-
-                    ) : () ),
                 ),
 
                 # laam + vowel + 'alif + vowel .. internal substitution with wa.sla
                 (
-                    ( $option{'font-fixing'} ? (
-
                     map {
 
                         my $double = $_;
@@ -1622,8 +1587,6 @@ sub demoder ($$@) {
                         } "\x{064E}", "\x{064F}", "\x{0650}"
 
                     } "", "\x{0651}"
-
-                    ) : () ),
                 ),
 
                 # optional ligatures to enforce here
@@ -1651,6 +1614,11 @@ __END__
 Encode::Arabic::ArabTeX::Verbatim - Interpreter of the Verbatim variant of the ArabTeX notation
 
 
+=head1 REVISION
+
+    $Revision: 143 $        $Date: 2006-11-15 02:16:57 +0100 (Wed, 15 Nov 2006) $
+
+
 =head1 SYNOPSIS
 
     use Encode::Arabic::ArabTeX::Verbatim;  # imports just like 'use Encode' would, plus extended options
@@ -1698,12 +1666,16 @@ Klaus Lagally       L<http://www.informatik.uni-stuttgart.de/ifi/bs/people/lagal
 
 =head1 AUTHOR
 
-Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
+Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
+
+    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
+
+Perl is also designed to make the easy jobs not that easy ;)
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2008 Otakar Smrz
+Copyright 2005-2006 by Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
